@@ -35,15 +35,15 @@ class SnippetVariableDialog : public QDialog
 public:
     SnippetVariableDialog(const QString &variableName, QMap<QString, QString> *variables, QWidget *parent = nullptr);
 
-    QString variableValue() const;
-    bool saveVariableIsChecked() const;
+    Q_REQUIRED_RESULT QString variableValue() const;
+    Q_REQUIRED_RESULT bool saveVariableIsChecked() const;
 
 private:
     void slotAccepted();
     QString mVariableName;
-    QMap<QString, QString> *mVariables;
-    KPIMTextEdit::PlainTextEditorWidget *mVariableValueText;
-    QCheckBox *mSaveVariable;
+    QMap<QString, QString> *mVariables = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *mVariableValueText = nullptr;
+    QCheckBox *mSaveVariable = nullptr;
 };
 }
 
